ANNOTATE
Presets
XGA 1024 × 768
Default 1200 × 800
Full HD 1920 × 1080
QHD 2560 × 1440
4K UHD 3840 × 2160
Network Diagram
Large Topo 2400 × 1600
XL Topo 3200 × 2400
XXL Topo 4000 × 3000
Custom
×
📐
Drop a topology image here
or LOAD IMAGE — annotate with pen, lines, arrows, text
P=pen L=line A=arrow T=text E=eraser H=pan Ctrl+Z=undo
TYPE LABEL — ENTER TO PLACE
PEN | 4px P=pen L=line A=arrow T=text E=eraser H=pan 0 annotations 100%